.. _apps-test:

=============================
Asynchronous Test Suite
=============================

.. automodule:: pulsar.apps.test


API
=========

TestSuite
~~~~~~~~~~~~~~~~~~~

.. autoclass:: TestSuite
   :members:
   :member-order: bysource
   
   
TestPlugin
~~~~~~~~~~~~~~~~~~~

.. autoclass:: TestPlugin
   :members:
   :member-order: bysource


TestLoader
~~~~~~~~~~~~~~~~~~~

.. autoclass:: TestLoader
   :members:
   :member-order: bysource
   

Plugin
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: Plugin
   :members:
   :member-order: bysource
   
   
TestRunner
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: TestRunner
   :members:
   :member-order: bysource
   
   
TestRequest
~~~~~~~~~~~~~~~~~~~

.. autoclass:: TestRequest
   :members:
   :member-order: bysource
   
   
run_on_arbiter
~~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: run_on_arbiter
